Changelog
=========


1.1 (2016-10-28)
----------------

- Add support for helpers
  [tomgross]


1.0 (2016-10-28)
----------------

- Add persistent tile wrapper
  [tomgross]

- Unify names. It is now **HandlebarsTile**
  [tomgross]


1.0rc1 (2016-08-29)
-------------------

- Add registry for templates
  [tomgross]

- Fix i18n translate tests
  [tomgross]


1.0b1 (2016-07-25)
------------------

- Initial release.
  [tomgross]
